@@ -36,6 +36,10 @@ from flake8_pie.pie803_prefer_logging_interpolation import (
     pie803_prefer_logging_interpolation,
 )
 from flake8_pie.pie804_no_unnecessary_dict_kwargs import pie804_no_dict_kwargs
+from flake8_pie.pie805_prefer_literal import pie805_prefer_literal
+from flake8_pie.pie806_no_assert_except import pie806_no_assert_except
+from flake8_pie.pie807_pefer_list_builtin import pie807_prefer_list_builtin
+from flake8_pie.pie808_prefer_simple_range import pie808_prefer_simple_range
 
 
 @dataclass(frozen=True)
@@ -94,6 +98,8 @@ class Flake8PieVisitor(ast.NodeVisitor):
         pie802_prefer_simple_any_all(node, self.errors)
         pie803_prefer_logging_interpolation(node, self.errors)
         pie804_no_dict_kwargs(node, self.errors)
+        pie805_prefer_literal(node, self.errors)
+        pie808_prefer_simple_range(node, self.errors)
 
         self.generic_visit(node)
 
@@ -131,6 +137,7 @@ class Flake8PieVisitor(ast.NodeVisitor):
 
     def visit_Try(self, node: ast.Try) -> None:
         self._visit_body(node)
+        pie806_no_assert_except(node, self.errors)
 
         self.generic_visit(node)
 
@@ -141,6 +148,10 @@ class Flake8PieVisitor(ast.NodeVisitor):
         pie797_no_unnecessary_if_expr(node, self.errors)
         self.generic_visit(node)
 
+    def visit_Lambda(self, node: ast.Lambda) -> None:
+        pie807_prefer_list_builtin(node, self.errors)
+        self.generic_visit(node)
+
     def _visit_body(self, node: Body) -> None:
         pie781_assign_and_return(node, self.errors)
         pie790_no_unnecessary_pass(node, self.errors)
